Simplified SDK for many APIs.

# Installing

```bash
pip install abstra-connectors
```

# Connectors

- [abstra](./connectors/abstra)
- [airtable](./connectors/airtable)
- [clicksign](./connectors/clicksign)
- [clickup](./connectors/clickup)
- [discord](./connectors/discord)
- [docusign](./connectors/docusign)
- [google_calendar](./connectors/google_calendar)
- [google_drive](./connectors/google_drive)
- [google_sheets](./connectors/google_sheets)
- [linkedin](./connectors/linkedin)
- [microsoft_teams](./connectors/microsoft_teams)
- [monday](./connectors/monday)
- [openai](./connectors/openai)
- [salesforce](./connectors/salesforce)
- [slack](./connectors/slack)
- [telegram](./connectors/telegram)
- [whatsapp](./connectors/whatsapp)
